PyBaccarat: Packages

PyBaccarat visit the ministry of silly walks

Packages
Here are the packages with brief descriptions (if available):
[detail level 12]

▼N pybaccarat | This module is collection of classes used with playing the game Baccarat
N baccarat | This module is collection of classes used with playing the game Baccarat
N baccaratsystems | This module is collection of classes used with systems for playing the game Baccarat
N playingcards | This module is collection of classes used with playing Cards
▼Ntests |
N test_card | Unit test for the Card class
N test_hand |
N test_scoreboard | Unit test for the Card class
N test_shoe | Unit test for the Shoe class
N test_ties | Unit test for the Ties class